"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var fs = require("fs");
var path = require("path");
var plugin_1 = require("stryker-api/plugin");
exports.DEPRECATED_CONFIG_KEY_FILE = 'babelrcFile';
exports.DEPRECATED_CONFIG_KEY_OPTIONS = 'babelConfig';
exports.CONFIG_KEY = 'babel';
exports.FILE_KEY = 'optionsFile';
exports.OPTIONS_KEY = 'options';
exports.EXTENSIONS_KEY = 'extensions';
var DEFAULT_BABEL_CONFIG = Object.freeze({
    extensions: Object.freeze([]),
    options: Object.freeze({}),
    optionsFile: '.babelrc'
});
var BabelConfigReader = /** @class */ (function () {
    function BabelConfigReader(log) {
        this.log = log;
    }
    BabelConfigReader.prototype.readConfig = function (strykerOptions) {
        var babelConfig = tslib_1.__assign({}, DEFAULT_BABEL_CONFIG, strykerOptions[exports.CONFIG_KEY]);
        this.loadDeprecatedOptions(strykerOptions, babelConfig);
        babelConfig.options = tslib_1.__assign({}, this.readBabelOptionsFromFile(babelConfig.optionsFile), babelConfig.options);
        this.log.debug("Babel config is: " + JSON.stringify(babelConfig, null, 2));
        return babelConfig;
    };
    BabelConfigReader.prototype.loadDeprecatedOptions = function (strykerOptions, babelConfig) {
        if (strykerOptions[exports.DEPRECATED_CONFIG_KEY_OPTIONS]) {
            babelConfig.options = strykerOptions[exports.DEPRECATED_CONFIG_KEY_OPTIONS];
            this.log.warn("\"" + exports.DEPRECATED_CONFIG_KEY_OPTIONS + "\" is deprecated, please use { " + exports.CONFIG_KEY + ": { " + exports.OPTIONS_KEY + ": " + JSON.stringify(babelConfig.options) + " }");
        }
        if (strykerOptions[exports.DEPRECATED_CONFIG_KEY_FILE]) {
            babelConfig.optionsFile = strykerOptions[exports.DEPRECATED_CONFIG_KEY_FILE];
            this.log.warn("\"" + exports.DEPRECATED_CONFIG_KEY_FILE + "\" is deprecated, please use { " + exports.CONFIG_KEY + ": { " + exports.FILE_KEY + ": '" + babelConfig.optionsFile + "' } }");
        }
    };
    BabelConfigReader.prototype.readBabelOptionsFromFile = function (relativeFileName) {
        if (relativeFileName) {
            var babelrcPath = path.resolve(relativeFileName);
            this.log.debug("Reading .babelrc file from path \"" + babelrcPath + "\"");
            if (fs.existsSync(babelrcPath)) {
                try {
                    var config = JSON.parse(fs.readFileSync(babelrcPath, 'utf8'));
                    return config;
                }
                catch (error) {
                    this.log.error("Error while reading \"" + babelrcPath + "\" file: " + error);
                }
            }
            else {
                this.log.error("babelrc file does not exist at: " + babelrcPath);
            }
        }
        return {};
    };
    BabelConfigReader.inject = plugin_1.tokens(plugin_1.commonTokens.logger);
    return BabelConfigReader;
}());
exports.BabelConfigReader = BabelConfigReader;
//# sourceMappingURL=BabelConfigReader.js.map